@@ -59,7 +59,6 @@ fetch_ladder <- function(season = NULL,
                          comp = "AFLM",
                          source = "AFL",
                          ...) {
-
   # Do some data checks
   season <- check_season(season)
   check_comp_source(comp, source)
@@ -71,33 +70,32 @@ fetch_ladder <- function(season = NULL,
     NULL
   )
 
-  if (is.null(dat)) rlang::warn(glue::glue("The source \"{source}\" does not have Ladder data. Please use one of \"AFL\", \"afltables\", or \"squiggle\""))
+  if (is.null(dat)) cli::cli_warn("The source \"{source}\" does not have Ladder data. Please use one of \"AFL\", \"afltables\", or \"squiggle\"")
   return(dat)
 }
 
 #' @rdname fetch_ladder
 #' @export
 fetch_ladder_afl <- function(season = NULL, round_number = NULL, comp = "AFLM") {
-
   # check inputs
   season <- check_season(season)
   comp <- check_comp(comp)
   # if (is.null(round_number)) round_number <- ""
 
   if (length(season) > 1) {
-    rlang::inform("Multiple seasons specified, ignoring round_number")
+    cli::cli_inform("Multiple seasons specified, ignoring round_number")
     round_number <- NULL
   }
   # fetch ids
   season_id <- find_season_id(season, comp)
 
   if (is.null(season_id)) {
-    rlang::warn(glue::glue("No ladder data found for season {season} on AFL.com.au for {comp}"))
+    cli::cli_warn("No ladder data found for season {season} on AFL.com.au for {comp}")
     return(NULL)
   }
 
   if (is.null(round_number)) {
-    rlang::inform("No round number specified, trying to return most recent ladder for specified season")
+    cli::cli_inform("No round number specified, trying to return most recent ladder for specified season")
     round_id <- ""
   } else {
     round_id <- find_round_id(round_number,
@@ -120,13 +118,13 @@ fetch_ladder_afl <- function(season = NULL, round_number = NULL, comp = "AFLM")
     ))
 
   resp <- api_url %>%
-    purrr::map(httr::GET, query = list("roundId" = round_id))
+    purrr::map(httr::GET, query = list("roundId" = round_id), .progress = TRUE)
 
   status_codes <- resp %>%
     purrr::map_dbl(purrr::pluck, "status_code")
 
   if (any(status_codes == 404) | any(status_codes == 400)) {
-    rlang::abort(glue::glue("No data found for specified round number and season. Does round number \"{round_number}\" exist for Season \"{season}\" on \"www.afl.com.au/ladder\"?"))
+    cli::cli_abort("No data found for specified round number and season. Does round number \"{round_number}\" exist for Season \"{season}\" on \"www.afl.com.au/ladder\"?")
   }
 
   cont <- resp %>%
@@ -178,8 +176,10 @@ fetch_ladder_afl <- function(season = NULL, round_number = NULL, comp = "AFLM")
 #' @export
 fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_results_df = NULL) {
   suppressWarnings(if (is.null(match_results_df)) {
-    match_results_df <- purrr::map_dfr(.x = c(1:round_number),
-                                       .f  = ~fetch_results_afltables(season, .x))
+    match_results_df <- purrr::map_dfr(
+      .x = c(1:round_number),
+      .f = ~ fetch_results_afltables(season, .x)
+    )
   })
 
   # first some cleaning up
@@ -197,7 +197,7 @@ fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_res
   home_dat <- match_results_df %>%
     dplyr::select(
       Team = "Home.Team",
-      "Round.Number", "Season","winner", 
+      "Round.Number", "Season", "winner",
       Score = "Home.Points",
       OppScore = "Away.Points"
     ) %>%
@@ -228,12 +228,16 @@ fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_res
   # ie in some rounds, there aren't the right amount of teams in each round
   df <- team_view %>%
     dplyr::distinct(.data$Season, .data$Team) %>%
-    dplyr::left_join(team_view %>% dplyr::distinct(.data$Season, .data$Round.Number), 
-      by = "Season", 
-      multiple = "all") %>%
-    dplyr::left_join(team_view, 
-                     by = c("Season", "Round.Number", "Team"), 
-                     multiple = "all") %>%
+    dplyr::left_join(team_view %>% dplyr::distinct(.data$Season, .data$Round.Number),
+      by = "Season",
+      multiple = "all",
+      relationship = "many-to-many"
+    ) %>%
+    dplyr::left_join(team_view,
+      by = c("Season", "Round.Number", "Team"),
+      multiple = "all",
+      relationship = "many-to-many"
+    ) %>%
     dplyr::select(-"winner", -"home_or_away")
 
 
@@ -284,12 +288,13 @@ fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_res
 
   # select final columns for output ladder table
   ladder <- ladder %>%
-    dplyr::select("Season", "Team", "Round.Number", 
-                  Season.Points = "season_points", 
-                  Score.For = "score_for", 
-                  Score.Against = "score_against", 
-                  Percentage = "percentage", 
-                  Ladder.Position = "ladder_pos")
+    dplyr::select("Season", "Team", "Round.Number",
+      Season.Points = "season_points",
+      Score.For = "score_for",
+      Score.Against = "score_against",
+      Percentage = "percentage",
+      Ladder.Position = "ladder_pos"
+    )
 
 
   # Allowing for ladder filtering -------------------------------------------
@@ -306,7 +311,7 @@ fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_res
   })
 
   if (nrow(ladder) == 0) {
-    rlang::abort(glue::glue("No data found for specified round number and season. Does round number \"{round_number}\" exist for Season \"{season}\" on \"www.afltables.com\"?"))
+    cli::cli_abort("No data found for specified round number and season. Does round number \"{round_number}\" exist for Season \"{season}\" on \"www.afltables.com\"?")
   }
 
   return(ladder)
@@ -318,19 +323,21 @@ fetch_ladder_afltables <- function(season = NULL, round_number = NULL, match_res
 #' @export
 fetch_ladder_squiggle <- function(season = NULL,
                                   round_number = NULL) {
-
   # check inputs
   season <- check_season(season)
 
   if (is.null(round_number)) {
-    cli::cli_alert_info(
-      "No round specified - returning results for all rounds in {.val {season}}"
+    cli::cli_progress_step(
+      "No round specified - returning most recent ladder in season {.val {season}}"
     )
     dat <- fetch_squiggle_data(
       query = "standings",
       year = season
     )
   } else {
+    cli::cli_progress_step(
+      "Returning ladder as of round {.val {round_number}} in season {.val {season}}"
+    )
     dat <- fetch_squiggle_data(
       query = "standings",
       year = season,
