@@ -5,43 +5,43 @@
 #' @param comp "AFLM" or "AFLW"
 #' @keywords internal
 #' @noRd
-fetch_teams_afl <- function(comp){
-  
+fetch_teams_afl <- function(comp) {
   team_api <- function(page) {
     api <- "https://aflapi.afl.com.au/afl/v2/teams"
-    
+
     resp <- httr::GET(
       url = api,
-      query = list("pageSize" = "1000", 
-                   page = page))
-    
+      query = list(
+        "pageSize" = "1000",
+        page = page
+      )
+    )
+
     cont <- parse_resp_afl(resp)
   }
-  
+
   cont <- team_api(0)
-  
-  #check_for_more
+
+  # check_for_more
   if (cont$meta$pagination$numPages > 1) {
     page_ind <- 0:(cont$meta$pagination$numPages - 1)
-    
+
     teams <- page_ind %>%
       purrr::map(team_api) %>%
       purrr::map_dfr(purrr::pluck, "teams")
-    
-    
   } else {
     teams <- cont$teams
   }
-  
-  
+
+
   df <- teams %>%
     dplyr::select(
       "id", "abbreviation",
       "name", "teamType",
-      "club.id","club.providerId","club.name","club.abbreviation","club.nickname"
+      "club.id", "club.providerId", "club.name", "club.abbreviation", "club.nickname"
     ) %>%
     stats::na.omit()
-  
+
   type <- dplyr::case_when(
     comp == "AFLM" ~ "MEN",
     comp == "AFLW" ~ "WOMEN",
@@ -53,11 +53,12 @@ fetch_teams_afl <- function(comp){
     is.null(comp) ~ "ALL",
     TRUE ~ ""
   )
-  
-  if (type == "ALL") return(df)
-  
+
+  if (type == "ALL") {
+    return(df)
+  }
+
   df[df$teamType == type, ]
-  
 }
 
 
@@ -71,11 +72,10 @@ fetch_teams_afl <- function(comp){
 #' @keywords internal
 #' @noRd
 find_team_id <- function(team_abr, comp = "AFLM") {
-  
   check_comp(comp)
-  
+
   df <- fetch_teams_afl(comp)
-  
+
   if (is.null(team_abr)) {
     return(df)
   }
@@ -90,12 +90,13 @@ find_team_id <- function(team_abr, comp = "AFLM") {
 #' @keywords internal
 #' @noRd
 team_check_afl <- function(team) {
-  rlang::warn("In future versions of `fetch_player_details`, teams will need to match the official AFL API teams. 
+  cli::cli_warn("In future versions of `fetch_player_details`, teams will need to match the official AFL API teams.
               You can use `official_teams = TRUE` to test this behaviour and change your code before this breaking change",
-              .frequency = "regularly",
-              .frequency_id = "fpd_depr",
-              id = "fpd_depr")
-  
+    .frequency = "regularly",
+    .frequency_id = "fpd_depr",
+    id = "fpd_depr"
+  )
+
   valid_teams <- c(
     "Adelaide", "Brisbane Lions",
     "Carlton", "Collingwood", "Essendon",
@@ -105,29 +106,26 @@ team_check_afl <- function(team) {
     "Sydney", "West Coast",
     "Western Bulldogs"
   )
-  
-  valid <- team %in% valid_teams
-  
-  if (!valid) {
-    rlang::abort(glue::glue("{team} is not a valid input for afl teams.
-                            Should be one of {glue::glue_collapse(valid_teams, sep = \", \")} "))
-  }
-  
 
+  valid <- team %in% valid_teams
+
+  if (!valid) {
+    cli::cli_abort("{team} is not a valid input for afl teams.
+                            Should be one of {glue::glue_collapse(valid_teams, sep = \", \")} ")
+  }
 }
 
 #' Internal function to return team name abbreviation for AFL API
 #' @param team Team name
 #' @export
 team_abr_afl <- function(team) {
-  
-  
-  rlang::warn("In future versions of `fetch_player_details`, teams will need to match the official AFL API teams. 
+  cli::cli_warn("In future versions of `fetch_player_details`, teams will need to match the official AFL API teams.
               You can use `official_teams = TRUE` to test this behaviour and change your code before this breaking change",
-              .frequency = "regularly",
-              .frequency_id = "fpd_depr",
-              id = "fpd_depr")
-  
+    .frequency = "regularly",
+    .frequency_id = "fpd_depr",
+    id = "fpd_depr"
+  )
+
   # Internal function
   dplyr::case_when(
     team == "Adelaide" ~ "ADEL",
@@ -149,7 +147,6 @@ team_abr_afl <- function(team) {
     team == "West Coast" ~ "WCE",
     TRUE ~ team
   )
-
 }
 
 
@@ -160,15 +157,14 @@ team_abr_afl <- function(team) {
 #' @keywords internal
 #' @noRd
 team_check_afl2 <- function(team, comp = "AFLM") {
-  
   valid_teams <- fetch_teams_afl(comp)
-  
+
 
   valid <- team %in% valid_teams$name
 
   if (!valid) {
-    rlang::abort(glue::glue("\"{team}\" is not a valid input for afl teams for the \"{comp}\" comp.
-                            Run `fetch_teams_afl(\"{comp}\")` to see a list of valid teams"))
+    cli::cli_abort("\"{team}\" is not a valid input for afl teams for the \"{comp}\" comp.
+                            Run `fetch_teams_afl(\"{comp}\")` to see a list of valid teams")
   }
 }
 
@@ -177,12 +173,10 @@ team_check_afl2 <- function(team, comp = "AFLM") {
 #' @param comp Competition
 #' @keywords internal
 #' @export
-team_abr_afl2 <- function(team, comp ="AFLM") {
-  
+team_abr_afl2 <- function(team, comp = "AFLM") {
   teams <- fetch_teams_afl(comp)
-  
+
   teams$abbreviation[teams$name == team]
-  
 }
 
 #' Find Comp ID
@@ -202,8 +196,8 @@ find_comp_id <- function(comp) {
   resp <- httr::GET(api_url)
 
   cont <- parse_resp_afl(resp)
-  
-  cont$competitions <- cont$competitions %>% 
+
+  cont$competitions <- cont$competitions %>%
     dplyr::filter(!stringr::str_detect(.data$name, "Legacy"))
 
   if (comp == "AFLM") comp <- "AFL"
@@ -245,7 +239,7 @@ find_season_id <- function(season, comp = "AFLM") {
   comp_id <- find_comp_id(comp)
 
   api <- httr::modify_url("https://aflapi.afl.com.au",
-    path = paste0("/afl/v2/competitions/", comp_id, "/compseasons")
+    path = paste0("/afl/v2/competitions/", comp_id, "/compseasons", "?pageSize=100")
   )
 
   resp <- httr::GET(api)
@@ -261,7 +255,7 @@ find_season_id <- function(season, comp = "AFLM") {
   id <- id[!is.na(id)]
 
   if (length(id) < 1) {
-    rlang::warn(glue::glue("Could not find a matching ID to the {comp} for {season}"))
+    cli::cli_warn("Could not find a matching ID to the {comp} for {season}")
     return(NULL)
   }
   return(id)
@@ -319,7 +313,7 @@ find_round_id <- function(round_number, season = NULL,
 
 
   if (length(id) < 1) {
-    rlang::warn(glue::glue("No data found for specified round number and season"))
+    cli::cli_warn("No data found for specified round number and season")
     return(NULL)
   }
   return(id)
@@ -345,9 +339,9 @@ fetch_match_roster_afl <- function(id, cookie = NULL) {
       "x-media-mis-token" = cookie
     )
   )
-  
-  if(httr::status_code(resp) == 404) {
-    cli::cli_alert_warning("No match found for match ID {.val {id}}. Returning NULL")
+
+  if (httr::status_code(resp) == 404) {
+    cli::cli_warn("No match found for match ID {.val {id}}. Returning NULL")
     return(NULL)
   }
   cont <- parse_resp_afl(resp)
@@ -476,7 +470,7 @@ fetch_round_results_afl <- function(id, cookie = NULL) {
 #' @keywords internal
 #' @noRd
 fetch_squad_afl <- function(teamId, team, season, compSeasonId) {
-  cli_team <- cli::cli_process_start("Fetching player details for {team}, {season}")
+  cli::cli_progress_step("Fetching player details for {team}, {season}")
   api <- "https://aflapi.afl.com.au//afl/v2/squads"
 
   resp <- httr::GET(
@@ -488,15 +482,15 @@ fetch_squad_afl <- function(teamId, team, season, compSeasonId) {
     )
   )
 
-  if (httr::http_error(resp)) return(NULL)
+  if (httr::http_error(resp)) {
+    return(NULL)
+  }
   cont <- parse_resp_afl(resp)
 
   df <- dplyr::as_tibble(cont$squad$players)
 
   names(df) <- gsub("player.", "", names(df))
 
-  cli::cli_process_done(cli_team)
-
   df %>%
     dplyr::mutate(
       season = season,
@@ -519,7 +513,7 @@ fetch_squad_afl <- function(teamId, team, season, compSeasonId) {
 #' @noRd
 parse_resp_afl <- function(resp) {
   if (httr::http_type(resp) != "application/json") {
-    rlang::abort("API did not return json", call. = FALSE)
+    cli::cli_abort("API did not return json")
   }
 
   parsed <- resp %>%
@@ -527,11 +521,9 @@ parse_resp_afl <- function(resp) {
     jsonlite::fromJSON(flatten = TRUE)
 
   if (httr::http_error(resp)) {
-    rlang::abort(glue::glue(
+    cli::cli_abort(
       "GitHub API request failed
-      {httr::status_code(resp)} - {parsed$techMessage}"
-    ),
-    call. = FALSE
+        {httr::status_code(resp)} - {parsed$techMessage}"
     )
   }
   return(parsed)
