@@ -18,8 +18,8 @@ team_check_footywire <- function(team) {
   valid <- team %in% valid_teams
 
   if (!valid) {
-    rlang::abort(glue::glue("{team} is not a valid input for footywire teams.
-                            Should be one of {glue::glue_collapse(valid_teams, sep = \", \")} "))
+    cli::cli_abort("{team} is not a valid input for footywire teams.
+                            Should be one of {glue::glue_collapse(valid_teams, sep = \", \")} ")
   }
 
   valid
@@ -63,7 +63,6 @@ get_team_abrev_footywire <- function(team) {
 #' @keywords internal
 #' @noRd
 footywire_html <- function(x, id) {
-
   # First get extra information
   game_details <- x %>%
     rvest::html_node("tr:nth-child(2) .lnorm") %>%
@@ -94,6 +93,7 @@ footywire_html <- function(x, id) {
     rvest::html_text()
 
   # Now get the table data. The Home Team is in the 13th table
+
   home_stats <- x %>%
     rvest::html_nodes("table") %>%
     .[[13]] %>%
@@ -103,11 +103,16 @@ footywire_html <- function(x, id) {
       Opposition = away_team,
       Status = "Home"
     ) %>%
-    dplyr::mutate(dplyr::across(c(-"Player", 
-                                  -"Team",
-                                  -"Opposition", 
-                                  -"Status"), 
-                                as.numeric))
+    dplyr::mutate(
+      dplyr::across(
+        dplyr::where(is.character),
+        ~ dplyr::na_if(.x, "Unused Substitute")
+      )
+    ) %>%
+    dplyr::mutate(dplyr::across(
+      c(-"Player", -"Team", -"Opposition", -"Status"),
+      as.numeric
+    ))
 
   # Now get the table data
   away_stats <- x %>%
@@ -119,11 +124,16 @@ footywire_html <- function(x, id) {
       Opposition = home_team,
       Status = "Away"
     ) %>%
-    dplyr::mutate(dplyr::across(c(-"Player", 
-                                  -"Team",
-                                  -"Opposition", 
-                                  -"Status"), 
-                                as.numeric))
+    dplyr::mutate(
+      dplyr::across(
+        dplyr::where(is.character),
+        ~ dplyr::na_if(.x, "Unused Substitute")
+      )
+    ) %>%
+    dplyr::mutate(dplyr::across(
+      c(-"Player", -"Team", -"Opposition", -"Status"),
+      as.numeric
+    ))
 
   ## Add data to ind.table
   player_stats <- home_stats %>%
@@ -161,12 +171,13 @@ footywire_html <- function(x, id) {
 #' @keywords internal
 #' @noRd
 get_match_data <- function(id) {
-  rlang::inform(glue::glue("Getting data from footywire for match id {id}"))
   # Create URL
   default_url <- "http://www.footywire.com/afl/footy/ft_match_statistics?mid="
   basic_url <- paste(default_url, id, sep = "")
   advanced_url <- paste(default_url, id, "&advv=Y", sep = "")
 
+  cli::cli_progress_step("Getting data from footywire for match id {id}")
+
   # Check if URL exists
   footywire_basic <- tryCatch(
     xml2::read_html(basic_url),
@@ -188,13 +199,12 @@ get_match_data <- function(id) {
     if (advanced_empty) {
       stop("This function only works on matches from 2010 onwards")
     } else {
-
       # If it does, grab the basic data
       player_stats_basic <- footywire_html(footywire_basic, id)
 
       # If it does, create access the URL and create the data table.
       # Also merge with basic
-      Sys.sleep(2)
+      Sys.sleep(0.5)
 
       # Check if Advanced URL exists
       footywire_advanced <- tryCatch(
@@ -280,8 +290,9 @@ extract_footywire_match_table <- function(xml) {
   tbl <- tbl %>%
     dplyr::rename(Points = "Final") %>%
     dplyr::select(
-      "Team", 
-      "Points") %>%
+      "Team",
+      "Points"
+    ) %>%
     dplyr::mutate(Status = c("Home", "Away")) %>%
     tidyr::pivot_wider(
       names_from = "Status",
@@ -305,13 +316,13 @@ extract_footywire_match_table <- function(xml) {
       Venue = match_details$venue
     ) %>%
     dplyr::select(
-      "Date", 
-      "Time", 
-      "Round", 
+      "Date",
+      "Time",
+      "Round",
       "Venue",
-      "Home.Team", 
+      "Home.Team",
       "Away.Team",
-      "Home.Points", 
+      "Home.Points",
       "Away.Points"
     )
 
@@ -450,19 +461,18 @@ fetch_footywire_stats <- function(ids) {
   # Now get data
   # First, only proceed if we've accessed the URL
   length_ids <- length(ids)
-  id <- cli::cli_process_start("Getting data from {.url https://www.footywire.com} for {.val {length_ids}} match{?es}")
+  cli::cli_progress_step("Getting data from {.url https://www.footywire.com} for {.val {length_ids}} match{?es}")
 
   # Loop through data using map
   dat <- ids %>%
     purrr::map_df(~
-    get_match_data(id = .x))
+      get_match_data(id = .x))
 
   # Rearrange
   dat <- dat %>%
     dplyr::arrange(.data$Date, .data$Match_id, dplyr::desc(.data$Status))
 
   # Finish and return
-  cli::cli_process_done(id)
   return(dat)
 }
 
