@@ -1,28 +1,30 @@
 ## ----setup, include = FALSE---------------------------------------------------
-not_cran = identical(Sys.getenv("NOT_CRAN"), "true")
+not_cran <- identical(Sys.getenv("NOT_CRAN"), "true")
 online <- !is.null(curl::nslookup("r-project.org", error = FALSE))
 eval_param <- not_cran & online
 
 knitr::opts_chunk$set(
+  eval = eval_param,
+  message = FALSE,
+  warning = FALSE,
   collapse = TRUE,
-  comment = "#>",
-  eval = eval_param
+  comment = "#>"
 )
 
-results <- fitzRoy:::results
-fixture <- fitzRoy:::fixture
+
+results <- fitzRoy:::results_afltables_all
+fixture <- fitzRoy:::fixture_footywire_2019
 
 ## ----load_packages, eval=eval_param, message=FALSE, warning=FALSE-------------
+#  library(fitzRoy)
 #  library(dplyr)
 #  library(elo)
 #  library(lubridate)
-#  library(fitzRoy)
-#  
 
 ## ----load_data, eval=FALSE, include=TRUE--------------------------------------
 #  # Get data
-#  results <- fitzRoy::get_match_results()
-#  fixture <- fitzRoy::get_fixture(2019)
+#  results <- fitzRoy::fetch_results_afltables(1897:2019)
+#  fixture <- fitzRoy::fetch_fixture_footywire(2019)
 
 ## ----load_data2, eval=eval_param----------------------------------------------
 #  results <- results %>% filter(Date < "2019-01-01")
@@ -34,9 +36,7 @@ fixture <- fitzRoy:::fixture
 
 ## ----clean_results, eval=eval_param-------------------------------------------
 #  results <- results %>%
-#    mutate(seas_rnd = paste0(Season, ".", Round.Number),
-#           First.Game = ifelse(Round.Number == 1, TRUE, FALSE))
-#  
+#    mutate(seas_rnd = paste0(Season, ".", Round.Number))
 
 ## ----clean_fixture, eval=eval_param-------------------------------------------
 #  fixture <- fixture %>%
@@ -53,23 +53,24 @@ fixture <- fitzRoy:::fixture
 #  k_val <- 20 # update weighting factor
 
 ## ----margin_outcome, eval=eval_param------------------------------------------
-#  map_margin_to_outcome <- function(margin, marg.max = 80, marg.min = -80){
-#    norm <- (margin - marg.min)/(marg.max - marg.min)
-#    norm %>% pmin(1) %>% pmax(0)
+#  map_margin_to_outcome <- function(margin, marg.max = 80, marg.min = -80) {
+#    norm <- (margin - marg.min) / (marg.max - marg.min)
+#    norm %>%
+#      pmin(1) %>%
+#      pmax(0)
 #  }
 
 ## ----run_elo, eval=eval_param-------------------------------------------------
 #  # Run ELO
 #  elo.data <- elo.run(
 #    map_margin_to_outcome(Home.Points - Away.Points) ~
-#    adjust(Home.Team, HGA) +
+#      adjust(Home.Team, HGA) +
 #      Away.Team +
-#      group(seas_rnd) +
-#      regress(First.Game, 1500, carryOver),
+#      regress(Season, 1500, carryOver) +
+#      group(seas_rnd),
 #    k = k_val,
 #    data = results
 #  )
-#  
 
 ## ----print_results1, eval=eval_param------------------------------------------
 #  as.data.frame(elo.data) %>% tail()
